@@ -5,10 +5,9 @@ require 'benchmark/ips/stats/stats_metric'
 require 'benchmark/ips/stats/sd'
 require 'benchmark/ips/stats/bootstrap'
 require 'benchmark/ips/report'
-require 'benchmark/ips/noop_suite'
 require 'benchmark/ips/job/entry'
-require 'benchmark/ips/job/stdout_report'
-require 'benchmark/ips/job/noop_report'
+require 'benchmark/ips/job/stream_report'
+require 'benchmark/ips/job/multi_report'
 require 'benchmark/ips/job'
 
 # Performance benchmarking library
@@ -18,10 +17,10 @@ module Benchmark
   module IPS
 
     # Benchmark-ips Gem version.
-    VERSION = "2.11.0"
+    VERSION = "2.12.0"
 
     # CODENAME of current version.
-    CODENAME = "We Do This Once A Year"
+    CODENAME = "Long Awaited"
 
     # Measure code in block, each code's benchmarked result will display in
     # iteration per second with standard deviation in given time.
